import{g as l,c as e,o as r,F as c,p as d,b as t,t as s}from"./CgNmNnAO.js";import{f as n}from"./BKglUKAr.js";const f={class:"dark:bg-gray-700 bg-white grid grid-cols-1 gap-6 border dark:border-gray-600 rounded py-4 px-6"},b={class:"text-sm font-medium text-gray-500 dark:text-gray-400 truncate"},g={class:"text-sm font-semibold text-gray-900 dark:text-gray-100"},_=l({__name:"KeyValueTableSimple",props:{data:{}},setup(m){return(a,p)=>(r(),e("dl",f,[(r(!0),e(c,null,d(a.data,(o,i)=>(r(),e("div",{key:i,class:"flex justify-between items-center"},[t("div",b,s(o[0]),1),t("div",g,s(o[1]),1)]))),128))]))}}),y={width:800,height:380,crosshair:{mode:n.Normal}},x={chart:{layout:{background:{color:"#ffffff"},textColor:"rgba(33, 56, 77, 1)"},grid:{vertLines:{color:"#f1f1f1",visible:!1},horzLines:{color:"#f1f1f1",visible:!1}},priceScale:{borderColor:"rgba(197, 203, 206, 0.6)"},timeScale:{borderColor:"rgba(197, 203, 206, 0.6)",timeVisible:!0,secondsVisible:!1}}},k={chart:{layout:{background:{color:"#333333"},textColor:"#D1D5DB"},grid:{vertLines:{color:"#525252",visible:!1},horzLines:{color:"#525252",visible:!1}},priceScale:{borderColor:"#525252"},timeScale:{borderColor:"#525252",timeVisible:!0,secondsVisible:!1}}};export{_,k as d,x as l,y as s};
